Handle

Struct Handle 

pub struct Handle {
    pub id: HandleId,
    pub handle_type: HandleType,
    pub position: HandlePosition,
    pub connection_limit: Option<usize>,
    pub valid_connection_types: Option<Vec<String>>,
    pub style: Option<String>,
}
Connection handle on a node

Fields

id: HandleIdhandle_type: HandleTypeposition: HandlePositionconnection_limit: Option<usize>valid_connection_types: Option<Vec<String>>style: Option<String>

Implementations

Source

impl Handle

pub fn new( id: impl Into<HandleId>, handle_type: HandleType, position: HandlePosition, ) -> Self

Create a new handle

pub fn source(id: impl Into<HandleId>, position: HandlePosition) -> Self

Create a source handle

pub fn target(id: impl Into<HandleId>, position: HandlePosition) -> Self

Create a target handle

pub fn with_connection_limit(self, limit: usize) -> Self

Set connection limit

pub fn with_connection_types(self, types: Vec<String>) -> Self

Set valid connection types

pub fn with_style(self, style: impl Into<String>) -> Self

Set style

pub fn absolute_position(&self, node_pos: Position, node_size: Size) -> Position

Calculate absolute position of handle given node position and size

pub fn contains_point( &self, point: Position, node_pos: Position, node_size: Size, handle_size: f64, ) -> bool

Check if a point is within the handle’s bounds

pub fn can_connect_to(&self, other: &Handle) -> bool

Check if this handle can connect to another handle